@@ -1,11 +1,11 @@
-from .utils import get_boolean, get_random_color, get_unit, render
+from .utils import hash_code, get_boolean, get_random_color, get_unit, render
 
 ELEMENTS = 4
 SIZE = 80
 
 
 def generate_colors(name, colors):
-    num_from_name = hash(name)
+    num_from_name = hash_code(name)
 
     return [
         {
@@ -19,14 +19,16 @@ def generate_colors(name, colors):
     ]
 
 
-def bauhaus(name, colors, square):
+def bauhaus(name, *, colors, size, title, square):
     properties = generate_colors(name, colors)
     return render(
         "bauhaus.svg",
         {
+            "name": name,
             "properties": properties,
             "SIZE": SIZE,
-            "size": "80",
+            "size": size,
+            "title": title,
             "square": square,
         },
     )
