@@ -1,11 +1,11 @@
-from .utils import get_random_color, get_unit, render
+from .utils import hash_code, get_random_color, get_unit, render
 
 ELEMENTS = 3
 SIZE = 80
 
 
 def generate_colors(name, colors):
-    num_from_name = hash(name)
+    num_from_name = hash_code(name)
 
     return [
         {
@@ -19,9 +19,16 @@ def generate_colors(name, colors):
     ]
 
 
-def marble(name, colors, square):
+def marble(name, *, colors, size, title, square):
     properties = generate_colors(name, colors)
     return render(
         "marble.svg",
-        {"properties": properties, "SIZE": SIZE, "size": "80", "square": square},
+        {
+            "name": name,
+            "properties": properties,
+            "SIZE": SIZE,
+            "size": size,
+            "title": title,
+            "square": square,
+        },
     )
